Installation — unqlite-python 0.2.0 documentation

# Installation

You can use `pip` to install `unqlite`:

    pip install unqlite

The project is hosted at https://github.com/coleifer/unqlite-python and can be installed from source:

    git clone https://github.com/coleifer/unqlite-python
    cd unqlite-python
    python setup.py build
    python setup.py install

Note

`unqlite-python` depends on Cython to generate the Python extension. By default unqlite-python ships with a generated C source file, so it is not strictly necessary to install Cython in order to compile `unqlite-python`, but you may wish to install Cython to ensure the generated source is compatible with your setup.

After installing unqlite-python, you can run the unit tests by executing the tests module:

    python tests.py